##  LN.data.sort.pl
##
##  This Perl program takes a series of TABARI-formatted input files with LN record headers
##  listed in the file 'file.list'. For each file, it moves the individual record into
##  into a single string, sorts on that -- which will be date sort -- and then outputs it
##  to a file with the prefix 'sort.'
##   
##  TO RUN PROGRAM:
##
##  perl LN.data.sort.pl
##
##  PROGRAMMING NOTES:
##
##  1. On an XServe with 3-Gb of memory, this worked fine with 500,000 record files, and
##     probably could handle files at least twice that large.
##
##  SYSTEM REQUIREMENTS
##  This program has been successfully run under Mac OS 10.5; it is standard perl
##  so it should also run in Unix or Windows. 
##
##  PROVENANCE:
##  Programmer: Philip A. Schrodt
##              Kansas Event Data System Project
##              Center for International Political Analysis
##              University of Kansas 
##	            Lawrence, Kansas, 66045 U.S.A.
##	            http://web.ku.edu/keds
##
##	Copyright (c) 2009  Philip A. Schrodt.  All rights reserved.
##
## 	Redistribution and use in source and binary forms, with or without modification,
## 	are permitted under the terms of the GNU General Public License:
## 	http://www.opensource.org/licenses/gpl-license.html
##
##	Report bugs to: schrodt@ku.edu
##
##	For plausible indenting of this source code, set the tab size in your editor to "2"
##
##  REVISION HISTORY:
##  22-May-09:  Initial version
##
##  ----------------------------------------------------------------------------------

#!/usr/local/bin/perl

# ======== main program =========== #

open(FDIR,"file.list")  or die "Can\'t open file.list file; error $!";
while ($file_name = <FDIR>) {
	print $file_name;
	$output_name = ">sort.".$file_name;
	open(FIN,$file_name)  or die "Can\'t open input file; error $!";
	open(FOUT,$output_name) or die "Can\'t open output file ; error $!";
	@notsort = ();
	@sorted  = ();   # probably unnecessary...
	
	$ka = 0;
	while ($line = <FIN>) {
		if ($line =~ m/^\d\d\d\d\d\d /) {   # get the date and record number
			$new = $line;
			while ($line = <FIN>) {
				if (length($line) == 1) {last;}
				$new = $new.$line;
			}
			push @notsort, $new;
	#	  print $new;
	#	  if (++$ka > 10000) {last;}
		}
	}
	@sorted = sort {$a cmp $b	} @notsort;
	
	foreach $line (@sorted) {
		print FOUT $line;
		print FOUT "\n";
	}
	close(FOUT) or die "Can\'t close output file ; error $!";
	close(FIN) or die "Can\'t close input file ; error $!";
}
print "Program has finished!\n";
